@@ -54,7 +54,7 @@ clean_names.default <- function(x, ...) {
   if (is.null(x)) {
     return(x)
   }
-  cleaned <- unname(find_variables(x, flatten = TRUE))
+  cleaned <- unname(find_variables(x, flatten = TRUE, verbose = FALSE))
   .remove_values(cleaned, c("1", "0"))
 }
 
