@@ -142,17 +142,21 @@
 # as list, since we need these information throughout the functions to
 # calculate the variance components...
 #
-.get_variance_information <- function(x, faminfo, name_fun = "get_variances", verbose = TRUE, model_component = "conditional") {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package `lme4` needs to be installed to compute variances for mixed models.", call. = FALSE)
+.get_variance_information <- function(x,
+                                      faminfo,
+                                      name_fun = "get_variances",
+                                      verbose = TRUE,
+                                      model_component = "conditional") {
+
+  # installed?
+  check_if_installed("lme4", reason = "to compute variances for mixed models")
+
+  if (inherits(x, "lme")) {
+    check_if_installed("nlme", reason = "to compute variances for mixed models")
   }
 
-  if (inherits(x, "lme") && !requireNamespace("nlme", quietly = TRUE)) {
-    stop("Package `nlme` needs to be installed to compute variances for mixed models.", call. = FALSE)
-  }
-
-  if (inherits(x, "rstanarm") && !requireNamespace("rstanarm", quietly = TRUE)) {
-    stop("Package `rstanarm` needs to be installed to compute variances for mixed models.", call. = FALSE)
+  if (inherits(x, "rstanarm")) {
+    check_if_installed("rstanarm", reason = "to compute variances for mixed models")
   }
 
   # stanreg
@@ -303,9 +307,9 @@
 
     # cpglmm
   } else if (inherits(x, "cpglmm")) {
-    if (!requireNamespace("cplm", quietly = TRUE)) {
-      stop("Package 'cplm' required. Please install it.")
-    }
+    # installed?
+    check_if_installed("cplm")
+
     vals <- list(
       beta = cplm::fixef(x),
       X = cplm::model.matrix(x),
@@ -377,10 +381,6 @@
 
 
 
-
-
-
-
 # fixed effects variance ----
 
 .compute_variance_fixed <- function(vals) {
@@ -389,10 +389,6 @@
 
 
 
-
-
-
-
 # variance associated with a random-effects term (Johnson 2014) ----
 
 .compute_variance_random <- function(terms, x, vals) {
@@ -540,9 +536,8 @@
   # check if null-model could be computed
   if (!is.null(.null_model)) {
     if (inherits(.null_model, "cpglmm")) {
-      if (!requireNamespace("cplm", quietly = TRUE)) {
-        stop("Package 'cplm' required. Please install it.")
-      }
+      # installed?
+      check_if_installed("cplm")
       null_fixef <- unname(cplm::fixef(.null_model))
     } else {
       null_fixef <- unname(.collapse_cond(lme4::fixef(.null_model)))
@@ -557,8 +552,7 @@
       warning(format_message("Can't calculate model's distribution-specific variance. Results are not reliable."), call. = FALSE)
     }
     return(0)
-  }
-  else if (mu < 6) {
+  } else if (mu < 6) {
     if (verbose) {
       warning(format_message(sprintf("mu of %0.1f is too close to zero, estimate of %s may be unreliable.", mu, name)), call. = FALSE)
     }
@@ -752,9 +746,8 @@
 # Get distribution-specific variance for general and
 # undefined families / link-functions
 .variance_family_default <- function(x, mu, verbose) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package `lme4` needs to be installed to compute variances for mixed models.", call. = FALSE)
-  }
+  # installed?
+  check_if_installed("lme4")
 
   tryCatch(
     {
