@@ -27,18 +27,17 @@
 #'      \item \code{warmup}, number of warmups per chain
 #'    }
 #'
-#'
 #' @examples
-#' library(lme4)
-#' data(sleepstudy)
-#' m <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
-#' find_algorithm(m)
+#' if (require("lme4")) {
+#'   data(sleepstudy)
+#'   m <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
+#'   find_algorithm(m)
+#' }
 #' \dontrun{
 #' library(rstanarm)
 #' m <- stan_lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
 #' find_algorithm(m)
 #' }
-#'
 #' @export
 find_algorithm <- function(x, ...) {
   UseMethod("find_algorithm")
@@ -158,9 +157,8 @@ find_algorithm.speedlm <- function(x, ...) {
 
 #' @export
 find_algorithm.blavaan <- function(x, ...) {
-  if (!requireNamespace("blavaan", quietly = TRUE)) {
-    stop("Package 'blavaan' required for this function to work. Please install it.")
-  }
+  # installed?
+  check_if_installed("blavaan")
 
   list(
     "chains" = blavaan::blavInspect(x, "n.chains"),
