@@ -420,10 +420,10 @@ find_formula.betareg <- function(x, verbose = TRUE, ...) {
 
 #' @export
 find_formula.afex_aov <- function(x, verbose = TRUE, ...) {
-  if ("aov" %in% names(x)) {
-    find_formula(x$aov)
+  if (!is.null(x$aov)) {
+    find_formula(x$aov, verbose = verbose, ...)
   } else {
-    find_formula(x$lm)
+    find_formula(x$lm, verbose = verbose, ...)
   }
 }
 
@@ -662,6 +662,9 @@ find_formula.plm <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+find_formula.pgmm <- find_formula.plm
+
 
 #' @export
 find_formula.felm <- function(x, verbose = TRUE, ...) {
