@@ -1,6 +1,6 @@
-#' Compute Model's Predictions
+#' Model Predictions (robust)
 #'
-#' Compute Model's Predictions.
+#' The \code{get_predicted()} function is a robust, flexible and user-friendly alternative to base R \code{\link{predict}} function. Additional features and advantages include availability of uncertainty intervals (CI), bootstrapping, a more intuitive API and the support of more models than base R's \code{predict}. However, although the interface are simplified, it is still very important to read the documentation of the arguments. This is because making "predictions" (a lose term for a variety of things) is a non-trivial process, with lots of caveats and complications. Read the \code{Details} section for more information.
 #'
 #' @param x A statistical model (can also be a data.frame, in which case the
 #'   second argument has to be a model).
@@ -36,7 +36,7 @@
 #'   \code{\link{get_predicted_ci}}.
 #' @inheritParams get_df
 #'
-#' @seealso get_predicted_ci
+#' @seealso \code{\link{get_predicted_ci}}
 #'
 #' @return The fitted values (i.e. predictions for the response). For Bayesian
 #'   or bootstrapped models (when \code{iterations != NULL}), this will be a
@@ -87,7 +87,7 @@
 #' # Get CI
 #' as.data.frame(predictions)
 #'
-#' # Bootsrapped
+#' # Bootstrapped
 #' as.data.frame(get_predicted(x, iterations = 4))
 #' summary(get_predicted(x, iterations = 4)) # Same as as.data.frame(..., keep_iterations = F)
 #' @export
@@ -242,7 +242,7 @@ get_predicted.lmerMod <- function(x,
     )
   }
 
-  ci_data <- get_predicted_ci(x, predictions, data = args$data, ci_type = args$ci_type, ...)
+  ci_data <- get_predicted_ci(x, predictions, data = args$data, ci = ci, ci_type = args$ci_type, ...)
   out <- .get_predicted_transform(x, predictions, args, ci_data)
   .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
 }
@@ -511,6 +511,48 @@ get_predicted.crr <- function(x, verbose = TRUE, ...) {
 
 
 
+# FA / PCA -------------------------------------------------------------
+# ======================================================================
+
+
+#' @export
+get_predicted.principal <- function(x, data = NULL, ...) {
+  if(is.null(data)) {
+    out <- as.data.frame(x$scores)
+  } else {
+    out <- as.data.frame(stats::predict(x, data, ...))
+  }
+  class(out) <- c("get_predicted", class(out))
+  out
+}
+
+#' @export
+get_predicted.fa <- get_predicted.principal
+
+#' @export
+get_predicted.prcomp <- function(x, data = NULL, ...) {
+  if(is.null(data)) {
+    out <- as.data.frame(x$x)
+  } else {
+    out <- as.data.frame(stats::predict(x, data, ...))
+  }
+  class(out) <- c("get_predicted", class(out))
+  out
+}
+
+#' @export
+get_predicted.faMain <- function(x, data = NULL, ...) {
+  check_if_installed("fungible")
+
+  if (is.null(data)) {
+    stop("A dataframe (either the original of a new one) must be provided (`get_predicted(fa_results, data = df`).")
+  } else {
+    out <- as.data.frame(fungible::faScores(X = data, faMainObject = x)$fscores)
+  }
+  class(out) <- c("get_predicted", class(out))
+  out
+}
+
 
 # ====================================================================
 # Utils --------------------------------------------------------------
@@ -698,25 +740,24 @@ get_predicted.crr <- function(x, verbose = TRUE, ...) {
 
   # Using bootMer
   if (inherits(x, "merMod")) {
-    if (!requireNamespace("lme4", quietly = TRUE)) {
-      stop("Package `lme4` needed for this function to work. Please install it.")
-    }
+    # installed
+    check_if_installed("lme4")
+
     draws <- lme4::bootMer(x, predict_function, nsim = iterations, use.u = TRUE, ...)
 
     # Using boot
   } else {
-    if (!requireNamespace("boot", quietly = TRUE)) {
-      stop("Package `boot` needed for this function to work. Please install it.")
-    }
-    boot_fun <- function(data, indices, ...) {
-      model <- stats::update(x, data = data[indices, ])
+    check_if_installed("boot")
+
+    boot_fun <- function(data, indices, predict_data, ...) {
+      model <- stats::update(x, data = data[indices, , drop = FALSE])
       if (verbose) {
-        predict_function(model, data = data, ...)
+        predict_function(model, data = predict_data, ...)
       } else {
-        suppressWarnings(predict_function(model, data = data, ...))
+        suppressWarnings(predict_function(model, data = predict_data, ...))
       }
     }
-    draws <- boot::boot(data, boot_fun, R = iterations, ...)
+    draws <- boot::boot(data = get_data(x), boot_fun, R = iterations, predict_data = data, ...)
   }
 
   # Format draws
