@@ -3,15 +3,16 @@
 #' @export
 print.get_predicted <- function(x, ...) {
   print_colour("Predicted values:\n\n", "blue")
-  print(as.numeric(x))
+  if(is.null(ncol(x))) {
+    print.default(as.numeric(x))
+  } else {
+    print.data.frame(x)
+  }
   print_colour("\nNOTE: Confidence intervals, if available, are stored as attributes and can be acccessed using `as.data.frame()` on this output.", "yellow")
 }
 
 
 
-
-
-
 .print_bigdata <- function(x, nrows = 3, ncols = 3, ...) {
   out <- x[1:nrows, 1:ncols]
 
@@ -31,20 +32,23 @@ print.get_predicted <- function(x, ...) {
 
 
 
-
-
 # As data frame -----------------------------------------------------------
 
-
-
 #' @export
 as.data.frame.get_predicted <- function(x, ..., keep_iterations = TRUE) {
-  out <- data.frame("Predicted" = as.numeric(x))
-  if ("ci_data" %in% names(attributes(x))) {
-    out <- cbind(out, attributes(x)$ci_data)
-  }
-  if ("iterations" %in% names(attributes(x)) && keep_iterations == TRUE) {
-    out <- cbind(out, attributes(x)$iterations)
+  if(inherits(x, "data.frame") && !"iterations" %in% names(attributes(x))) {
+    # Then it must be a regular data.frame (e.g., from PCA/FA)
+    out <- as.data.frame.data.frame(x)
+
+  } else {
+    # Then it must be predictions from a regression model
+    out <- data.frame("Predicted" = as.numeric(x))
+    if ("ci_data" %in% names(attributes(x))) {
+      out <- cbind(out, attributes(x)$ci_data)
+    }
+    if ("iterations" %in% names(attributes(x)) && keep_iterations == TRUE) {
+      out <- cbind(out, attributes(x)$iterations)
+    }
   }
 
   out
@@ -59,8 +63,6 @@ summary.get_predicted <- function(object, ...) {
 
 
 
-
-
 #' @export
 as.matrix.get_predicted <- function(x, ...) {
   class(x) <- class(x)[class(x) != "get_predicted"]
