@@ -13,6 +13,10 @@
 #'   variance are the most computational intensive components, and hence may
 #'   take a few seconds to calculate.
 #' @param verbose Toggle off warnings.
+#' @param tolerance Tolerance for singularity check of random effects, to decide
+#'   whether to compute random effect variances or not. Indicates up to which
+#'   value the convergence result is accepted. The larger tolerance is, the
+#'   stricter the test will be. See \code{\link[performance:check_singularity]{check_singularity()}}.
 #' @param ... Currently not used.
 #'
 #' @return A list with following elements:
@@ -128,11 +132,11 @@ get_variance.default <- function(x, component = c("all", "fixed", "random", "res
 
 
 #' @export
-get_variance.merMod <- function(x, component = c("all", "fixed", "random", "residual", "distribution", "dispersion", "intercept", "slope", "rho01"), verbose = TRUE, ...) {
+get_variance.merMod <- function(x, component = c("all", "fixed", "random", "residual", "distribution", "dispersion", "intercept", "slope", "rho01"), verbose = TRUE, tolerance = 1e-5, ...) {
   component <- match.arg(component)
   tryCatch(
     {
-      .compute_variances(x, component = component, name_fun = "get_variance", name_full = "random effect variances", verbose = verbose)
+      .compute_variances(x, component = component, name_fun = "get_variance", name_full = "random effect variances", verbose = verbose, tolerance = tolerance)
     },
     error = function(e) {
       NULL
@@ -145,10 +149,10 @@ get_variance.merMod <- function(x, component = c("all", "fixed", "random", "resi
 get_variance.rlmerMod <- get_variance.merMod
 
 #' @export
-get_variance.cpglmm <- get_variance.merMod
+get_variance.mjoint <- get_variance.merMod
 
 #' @export
-get_variance.glmmTMB <- get_variance.merMod
+get_variance.cpglmm <- get_variance.merMod
 
 #' @export
 get_variance.glmmadmb <- get_variance.merMod
@@ -156,9 +160,6 @@ get_variance.glmmadmb <- get_variance.merMod
 #' @export
 get_variance.stanreg <- get_variance.merMod
 
-#' @export
-get_variance.MixMod <- get_variance.merMod
-
 #' @export
 get_variance.clmm <- get_variance.merMod
 
@@ -175,11 +176,27 @@ get_variance.lme <- get_variance.merMod
 get_variance.brmsfit <- get_variance.merMod
 
 
+#' @export
+get_variance.glmmTMB <- function(x, component = c("all", "fixed", "random", "residual", "distribution", "dispersion", "intercept", "slope", "rho01"), verbose = TRUE, tolerance = 1e-5, model_component = NULL, ...) {
+  component <- match.arg(component)
+  tryCatch(
+    {
+      .compute_variances(x, component = component, name_fun = "get_variance", name_full = "random effect variances", verbose = verbose, tolerance = tolerance, model_component = model_component)
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+}
 
 #' @export
-get_variance.mixed <- function(x, component = c("all", "fixed", "random", "residual", "distribution", "dispersion", "intercept", "slope", "rho01"), verbose = TRUE, ...) {
+get_variance.MixMod <- get_variance.glmmTMB
+
+
+#' @export
+get_variance.mixed <- function(x, component = c("all", "fixed", "random", "residual", "distribution", "dispersion", "intercept", "slope", "rho01"), verbose = TRUE, tolerance = 1e-5, ...) {
   component <- match.arg(component)
-  .compute_variances(x$full_model, component = component, name_fun = "get_variance", name_full = "random effect variances", verbose = verbose)
+  .compute_variances(x$full_model, component = component, name_fun = "get_variance", name_full = "random effect variances", verbose = verbose, tolerance = tolerance)
 }
 
 
@@ -197,8 +214,8 @@ get_variance_fixed <- function(x, verbose = TRUE, ...) {
 
 #' @rdname get_variance
 #' @export
-get_variance_random <- function(x, verbose = TRUE, ...) {
-  unlist(get_variance(x, component = "random", verbose = verbose, ...))
+get_variance_random <- function(x, verbose = TRUE, tolerance = 1e-5, ...) {
+  unlist(get_variance(x, component = "random", verbose = verbose, tolerance = tolerance, ...))
 }
 
 #' @rdname get_variance
