@@ -5,7 +5,7 @@
 #'
 #' @param x A model object.
 #'
-#' @return \code{TRUE} if \code{x} has an intercept, \code{FALSE} othwerwise.
+#' @return \code{TRUE} if \code{x} has an intercept, \code{FALSE} otherwise.
 #'
 #' @examples
 #' model <- lm(mpg ~ 0 + gear, data = mtcars)
@@ -14,13 +14,13 @@
 #' model <- lm(mpg ~ gear, data = mtcars)
 #' has_intercept(model)
 #'
-#' library(lme4)
-#' model <- lmer(Reaction ~ 0 + Days + (Days | Subject), data = sleepstudy)
-#' has_intercept(model)
-#'
-#' model <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
-#' has_intercept(model)
+#' if (require("lme4")) {
+#'   model <- lmer(Reaction ~ 0 + Days + (Days | Subject), data = sleepstudy)
+#'   has_intercept(model)
 #'
+#'   model <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
+#'   has_intercept(model)
+#' }
 #' @export
 has_intercept <- function(x) {
   if (is_multivariate(x)) {
@@ -31,5 +31,5 @@ has_intercept <- function(x) {
 }
 
 .check_for_intercept <- function(vars) {
-  !("0" %in% vars[["conditional"]])
-}
\ No newline at end of file
+  !any(c("0", "-1") %in% vars[["conditional"]])
+}
