@@ -1,8 +1,8 @@
 #' Standardize column names
 #'
-#' Standardize column names from data frames, in particular objects returned from
-#' \code{\link[parameters:model_parameters]{model_parameters()}}, so column names are
-#' consistent and the same for any model object.
+#' Standardize column names from data frames, in particular objects returned
+#' from \code{\link[parameters:model_parameters]{model_parameters()}}, so column
+#' names are consistent and the same for any model object.
 #'
 #' @param data A data frame. In particular, objects from \emph{easystats}
 #'   package functions like
@@ -30,11 +30,12 @@
 #'   kind of model was used in \code{model_parameters()}.
 #'   \cr \cr
 #'   For \code{style = "broom"}, column names are renamed to match \pkg{broom}'s
-#'   naming scheme, i.e. \code{Parameter} is renamed to \code{term}, \code{Coefficient}
-#'   becomes \code{estimate} and so on.
+#'   naming scheme, i.e. \code{Parameter} is renamed to \code{term},
+#'   \code{Coefficient} becomes \code{estimate} and so on.
 #'   \cr \cr
-#'   For \code{style = "easystats"}, when \code{data} is an object from \code{broom::tidy()},
-#'   column names are converted from "broom"-style into "easystats"-style.
+#'   For \code{style = "easystats"}, when \code{data} is an object from
+#'   \code{broom::tidy()}, column names are converted from "broom"-style into
+#'   "easystats"-style.
 #'
 #' @examples
 #' if (require("parameters")) {
@@ -140,8 +141,6 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
 
 
 
-
-
 .names_to_broom <- function(cn, ignore_estimate) {
   # TO DO: currently `htest` object output naming differs from `broom`
   # needs further discussion
@@ -152,6 +151,7 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
   cn[cn == "SD"] <- "std.dev"
   cn[cn == "p"] <- "p.value"
   cn[cn == "BF"] <- "bayes.factor"
+  cn[cn == "log_BF"] <- "log(bayes.factor)"
   cn[cn == "Component"] <- "component"
   cn[cn == "Effects"] <- "effect"
   cn[cn == "Response"] <- "response"
