@@ -1,8 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("robustbase")) {
-  context("insight, model_info")
-
   data(mtcars)
   m1 <- lmrob(mpg ~ gear + wt + cyl, data = mtcars)
 
@@ -45,7 +43,8 @@ if (require("testthat") &&
     expect_length(find_formula(m1), 1)
     expect_equal(
       find_formula(m1),
-      list(conditional = as.formula("mpg ~ gear + wt + cyl"))
+      list(conditional = as.formula("mpg ~ gear + wt + cyl")),
+      ignore_attr = TRUE
     )
   })
 
@@ -76,7 +75,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 4)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c("(Intercept)", "gear", "wt", "cyl")
     )
   })
